# -*- coding: utf-8 -*-

from tuikit.layout import AnchorLayout, OffsetLayout
from tuikit.scrollbar import VScrollbar
from tuikit.common import Borders


class ScrollView(AnchorLayout):
    """Scrolling view

    Shows scrollbars when needed.
    Scrolling area is determined according to child widget's size request.

    """

    def __init__(self):
        AnchorLayout.__init__(self)
        self._default_size.update(20, 20)

        self.inner = OffsetLayout()
        AnchorLayout.add(self, self.inner, halign='fill', valign='fill', margin=Borders(r=1))

        self.vscroll = VScrollbar()
        self.vscroll.add_handler('change', self._on_vscroll_change)
        AnchorLayout.add(self, self.vscroll, halign='right', valign='fill')

    def add(self, widget, **kwargs):
        self.inner.add(widget, **kwargs)
        widget.add_handler('sizereq', self._on_child_sizereq)
        widget.add_handler('spotmove', self._on_child_spotmove)

    def on_resize(self, ev):
        self._update_vscroll_max()

    def _on_vscroll_change(self, ev):
        self.inner.offset.y = - self.vscroll.scroll_pos

    def _on_child_sizereq(self, ev):
        self._update_vscroll_max()

    def _on_child_spotmove(self, ev):
        child = ev.originator
        spot = child.y - self.inner.offset.y + child.spot.y
        if spot < self.vscroll.scroll_pos:
            self.vscroll.scroll_pos = spot
        if spot > (self.height - 1) + self.vscroll.scroll_pos:
            self.vscroll.scroll_pos = spot - (self.height - 1)

    def _update_vscroll_max(self):
        max_height = 0
        for child in self.inner.children:
            child_height = child.y - self.inner.offset.y + child.sizereq.h
            if child_height > max_height:
                max_height = child_height
        if max_height < self.height:
            self.vscroll.hide()
        else:
            self.vscroll.scroll_max = max_height - self.height
            self.vscroll.show()

